@@ -6,10 +6,10 @@ import (
 	"time"
 
 	"github.com/containerd/log"
-	"github.com/docker/docker/pkg/archive"
-	"github.com/docker/docker/pkg/chrootarchive"
-	"github.com/docker/docker/pkg/idtools"
 	"github.com/docker/docker/pkg/ioutils"
+	"github.com/moby/go-archive"
+	"github.com/moby/go-archive/chrootarchive"
+	"github.com/moby/sys/user"
 )
 
 // ApplyUncompressedLayer defines the unpack method used by the graph
@@ -22,7 +22,7 @@ var ApplyUncompressedLayer = chrootarchive.ApplyUncompressedLayer
 // on the exported NewNaiveDiffDriver function below.
 type NaiveDiffDriver struct {
 	ProtoDriver
-	IDMap idtools.IdentityMapping
+	IDMap user.IdentityMapping
 	// If true, allow ApplyDiff to succeed in spite of failures to set
 	// extended attributes on the unpacked files due to the destination
 	// filesystem not supporting them or a lack of permissions. The
@@ -38,7 +38,7 @@ type NaiveDiffDriver struct {
 //	Changes(id, parent string) ([]archive.Change, error)
 //	ApplyDiff(id, parent string, diff archive.Reader) (size int64, err error)
 //	DiffSize(id, parent string) (size int64, err error)
-func NewNaiveDiffDriver(driver ProtoDriver, idMap idtools.IdentityMapping) Driver {
+func NewNaiveDiffDriver(driver ProtoDriver, idMap user.IdentityMapping) Driver {
 	return &NaiveDiffDriver{
 		ProtoDriver: driver,
 		IDMap:       idMap,
@@ -47,7 +47,7 @@ func NewNaiveDiffDriver(driver ProtoDriver, idMap idtools.IdentityMapping) Drive
 
 // Diff produces an archive of the changes between the specified
 // layer and its parent layer which may be "".
-func (gdw *NaiveDiffDriver) Diff(id, parent string) (arch io.ReadCloser, err error) {
+func (gdw *NaiveDiffDriver) Diff(id, parent string) (arch io.ReadCloser, retErr error) {
 	startTime := time.Now()
 	driver := gdw.ProtoDriver
 
@@ -58,8 +58,8 @@ func (gdw *NaiveDiffDriver) Diff(id, parent string) (arch io.ReadCloser, err err
 	layerFs := layerRootFs
 
 	defer func() {
-		if err != nil {
-			driver.Put(id)
+		if retErr != nil {
+			_ = driver.Put(id)
 		}
 	}()
 
@@ -131,7 +131,7 @@ func (gdw *NaiveDiffDriver) Changes(id, parent string) ([]archive.Change, error)
 // ApplyDiff extracts the changeset from the given diff into the
 // layer with the specified id and parent, returning the size of the
 // new layer in bytes.
-func (gdw *NaiveDiffDriver) ApplyDiff(id, parent string, diff io.Reader) (size int64, err error) {
+func (gdw *NaiveDiffDriver) ApplyDiff(id, parent string, diff io.Reader) (size int64, _ error) {
 	driver := gdw.ProtoDriver
 
 	// Mount the root filesystem so we can apply the diff/layer.
