@@ -350,11 +350,13 @@ func TestBridgeINC(t *testing.T) {
 // TestBridgeINCRouted makes sure a container on a gateway-mode=nat network can establish
 // a connection to a container on a gateway-mode=routed network, but not vice-versa.
 func TestBridgeINCRouted(t *testing.T) {
+	skip.If(t, testEnv.IsRootless(), "can't set filter-forward policy in rootless netns")
 	ctx := setupTest(t)
 
 	d := daemon.New(t)
 	d.StartWithBusybox(ctx, t)
 	t.Cleanup(func() { d.Stop(t) })
+	firewallBackend := d.FirewallBackendDriver(t)
 
 	c := d.NewClientT(t)
 	t.Cleanup(func() { c.Close() })
@@ -454,7 +456,7 @@ func TestBridgeINCRouted(t *testing.T) {
 	}
 
 	for _, fwdPolicy := range []string{"ACCEPT", "DROP"} {
-		networking.SetFilterForwardPolicies(t, fwdPolicy)
+		networking.SetFilterForwardPolicies(t, firewallBackend, fwdPolicy)
 		t.Run(fwdPolicy, func(t *testing.T) {
 			for _, tc := range testcases {
 				t.Run(tc.name+"/v4/ping", func(t *testing.T) {
@@ -508,23 +510,26 @@ func TestRoutedAccessToPublishedPort(t *testing.T) {
 	ctx := setupTest(t)
 
 	testcases := []struct {
-		name          string
-		userlandProxy bool
-		skipINC       bool
-		expResponse   bool
+		name                string
+		userlandProxy       bool
+		skipINC             bool
+		expResponseIptables bool
+		expResponseNftables bool
 	}{
 		{
-			name:          "proxy=true/skipICC=false",
-			userlandProxy: true,
-			expResponse:   true,
+			name:                "proxy=true/skipINC=false",
+			userlandProxy:       true,
+			expResponseIptables: true,
+			expResponseNftables: true,
 		},
 		{
-			name: "proxy=false/skipICC=false",
+			name:                "proxy=false/skipINC=false",
+			expResponseNftables: true,
 		},
 		{
-			name:        "proxy=false/skipICC=true",
-			skipINC:     true,
-			expResponse: true,
+			name:                "proxy=false/skipINC=true",
+			skipINC:             true,
+			expResponseIptables: true,
 		},
 	}
 
@@ -533,6 +538,10 @@ func TestRoutedAccessToPublishedPort(t *testing.T) {
 			d := daemon.New(t)
 			d.StartWithBusybox(ctx, t, "--ipv6", "--userland-proxy="+strconv.FormatBool(tc.userlandProxy))
 			defer d.Stop(t)
+			usingNftables := d.FirewallBackendDriver(t) == "nftables"
+			if usingNftables && tc.skipINC {
+				t.Skip("Skipping iptables skip-INC test, using nftables")
+			}
 
 			c := d.NewClientT(t)
 			defer c.Close()
@@ -601,7 +610,7 @@ func TestRoutedAccessToPublishedPort(t *testing.T) {
 						container.WithNetworkMode(routedNetName),
 						container.WithCmd("wget", "-O-", "-T3", url),
 					)
-					if tc.expResponse {
+					if (usingNftables && tc.expResponseNftables) || (!usingNftables && tc.expResponseIptables) {
 						// 404 Not Found means the server responded, but it's got nothing to serve.
 						assert.Check(t, is.Contains(res.Stderr.String(), "404 Not Found"), "url: %s", url)
 					} else {
@@ -625,7 +634,7 @@ func TestDefaultBridgeIPv6(t *testing.T) {
 		},
 		{
 			name:          "IPv6 ULA",
-			fixed_cidr_v6: "fd00:1234::/64",
+			fixed_cidr_v6: "fd00:1235::/64",
 		},
 		{
 			name:          "IPv6 LLA only",
@@ -633,7 +642,7 @@ func TestDefaultBridgeIPv6(t *testing.T) {
 		},
 		{
 			name:          "IPv6 nonstandard LLA only",
-			fixed_cidr_v6: "fe80:1234::/64",
+			fixed_cidr_v6: "fe80:1236::/64",
 		},
 	}
 
@@ -731,16 +740,16 @@ func TestDefaultBridgeAddresses(t *testing.T) {
 					// Modify that prefix, the default bridge's address must be deleted and re-added.
 					// The bridge must still have an address in the required (standard) LL subnet.
 					stepName:    "Nonstandard LL prefix - address change",
-					fixedCIDRV6: "fe80:1234::/32",
-					expAddrs:    []string{"fe80:1234::1/32", "fe80::"},
+					fixedCIDRV6: "fe80:1237::/32",
+					expAddrs:    []string{"fe80:1237::1/32", "fe80::"},
 				},
 				{
 					// Modify the prefix length, the addresses should not change.
 					stepName:    "Modify LL prefix - no address change",
-					fixedCIDRV6: "fe80:1234::/64",
+					fixedCIDRV6: "fe80:1238::/64",
 					// The prefix length displayed by 'ip a' is not updated - it's informational, and
 					// can't be changed without unnecessarily deleting and re-adding the address.
-					expAddrs: []string{"fe80:1234::1/", "fe80::"},
+					expAddrs: []string{"fe80:1238::1/", "fe80::"},
 				},
 			},
 		},
@@ -1030,16 +1039,23 @@ func TestNoIP6Tables(t *testing.T) {
 			id := container.Run(ctx, t, c, container.WithNetworkMode(netName))
 			defer c.ContainerRemove(ctx, id, containertypes.RemoveOptions{Force: true})
 
-			res, err := exec.Command("/usr/sbin/ip6tables-save").CombinedOutput()
-			assert.NilError(t, err)
-			if tc.expIPTables {
-				assert.Check(t, is.Contains(string(res), subnet))
-				assert.Check(t, is.Contains(string(res), bridgeName))
+			var cmd *exec.Cmd
+			if d.FirewallBackendDriver(t) == "nftables" {
+				cmd = exec.Command("nft", "list", "table", "ip6", "docker-bridges")
 			} else {
-				assert.Check(t, !strings.Contains(string(res), subnet),
-					fmt.Sprintf("Didn't expect to find '%s' in '%s'", subnet, string(res)))
-				assert.Check(t, !strings.Contains(string(res), bridgeName),
-					fmt.Sprintf("Didn't expect to find '%s' in '%s'", bridgeName, string(res)))
+				cmd = exec.Command("/usr/sbin/ip6tables-save")
+			}
+			res, err := cmd.CombinedOutput()
+			assert.NilError(t, err)
+			dump := string(res)
+			if tc.expIPTables {
+				assert.Check(t, is.Contains(dump, subnet))
+				assert.Check(t, is.Contains(dump, bridgeName))
+			} else {
+				assert.Check(t, !strings.Contains(dump, subnet),
+					fmt.Sprintf("Didn't expect to find '%s' in '%s'", subnet, dump))
+				assert.Check(t, !strings.Contains(dump, bridgeName),
+					fmt.Sprintf("Didn't expect to find '%s' in '%s'", bridgeName, dump))
 			}
 		})
 	}
@@ -1500,7 +1516,7 @@ func TestAdvertiseAddresses(t *testing.T) {
 				network.WithIPAM("172.22.22.0/24", "172.22.22.1"),
 			}, tc.netOpts...)
 			if tc.ipv6LinkLocal {
-				netOpts = append(netOpts, network.WithIPAM("fe80:1234::/64", "fe80:1234::1"))
+				netOpts = append(netOpts, network.WithIPAM("fe80:1240::/64", "fe80:1240::1"))
 			} else {
 				netOpts = append(netOpts, network.WithIPAM("fd3c:e70a:962c::/64", "fd3c:e70a:962c::1"))
 			}
@@ -1523,7 +1539,7 @@ func TestAdvertiseAddresses(t *testing.T) {
 			const ctr2Addr4 = "172.22.22.22"
 			ctr2Addr6 := "fd3c:e70a:962c::2222"
 			if tc.ipv6LinkLocal {
-				ctr2Addr6 = "fe80:1234::2222"
+				ctr2Addr6 = "fe80:1240::2222"
 			}
 			ctr2Id := container.Run(ctx, t, c,
 				container.WithName(ctr2Name),
@@ -1688,6 +1704,8 @@ func TestNetworkInspectGateway(t *testing.T) {
 func TestDropInForwardChain(t *testing.T) {
 	skip.If(t, networking.FirewalldRunning(), "can't use firewalld in host netns to add rules in L3Segment")
 	skip.If(t, testEnv.IsRootless, "rootless has its own netns")
+	skip.If(t, !strings.Contains(testEnv.FirewallBackendDriver(), "iptables"),
+		"test is iptables specific, and iptables isn't in use")
 
 	// Run the test in its own netns, to avoid interfering with iptables on the test host.
 	const l3SegHost = "difc"
